==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/floating_toolbar/fragment_background_image/FloatingToolbarFragmentBackgroundImagePanel.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/floating_toolbar/fragment_background_image/FloatingToolbarFragmentBackgroundImagePanel.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', './FloatingToolbarFragmentBackgroundImagePanelDelegateTemplate.soy', '../../../actions/updateEditableValue.es', '../../../store/ConnectedComponent.es', '../../../utils/FragmentsEditorDialogUtils', '../../../utils/constants', './FloatingToolbarFragmentBackgroundImagePanel.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.FloatingToolbarFragmentBackgroundImagePanel = exports.ConnectedFloatingToolbarFragmentBackgroundImagePanel = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  require("./FloatingToolbarFragmentBackgroundImagePanelDelegateTemplate.soy");

  var _updateEditableValue = require("../../../actions/updateEditableValue.es");

  var _ConnectedComponent = require("../../../store/ConnectedComponent.es");

  var _FragmentsEditorDialogUtils = require("../../../utils/FragmentsEditorDialogUtils");

  var _constants = require("../../../utils/constants");

  var _FloatingToolbarFragmentBackgroundImagePanel = _interopRequireDefault(require("./FloatingToolbarFragmentBackgroundImagePanel.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FloatingToolbarFragmentBackgroundImagePanel
   */
  var FloatingToolbarFragmentBackgroundImagePanel =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FloatingToolbarFragmentBackgroundImagePanel, _Component);

    function FloatingToolbarFragmentBackgroundImagePanel() {
      _classCallCheck(this, FloatingToolbarFragmentBackgroundImagePanel);

      return _possibleConstructorReturn(this, _getPrototypeOf(FloatingToolbarFragmentBackgroundImagePanel).apply(this, arguments));
    }

    _createClass(FloatingToolbarFragmentBackgroundImagePanel, [{
      key: "_handleSelectButtonClick",

      /**
       * Show image selector
       * @private
       * @review
       */
      value: function _handleSelectButtonClick() {
        var _this = this;

        (0, _FragmentsEditorDialogUtils.openImageSelector)({
          callback: function callback(image) {
            return _this._updateFragmentBackgroundImage(image);
          },
          imageSelectorURL: this.imageSelectorURL,
          portletNamespace: this.portletNamespace
        });
      }
      /**
       * Remove existing image if any
       * @private
       * @review
       */

    }, {
      key: "_handleClearButtonClick",
      value: function _handleClearButtonClick() {
        this._updateFragmentBackgroundImage('');
      }
      /**
       * Dispatches action to update editableValues with new background image url
       * @param {string} backgroundImageURL
       */

    }, {
      key: "_updateFragmentBackgroundImage",
      value: function _updateFragmentBackgroundImage(image) {
        this.store.dispatch((0, _updateEditableValue.updateEditableValueContentAction)(this.item.fragmentEntryLinkId, _constants.BACKGROUND_IMAGE_FRAGMENT_ENTRY_PROCESSOR, this.item.editableId, image));
      }
    }]);

    return FloatingToolbarFragmentBackgroundImagePanel;
  }(_metalComponent["default"]);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.FloatingToolbarFragmentBackgroundImagePanel = FloatingToolbarFragmentBackgroundImagePanel;
  FloatingToolbarFragmentBackgroundImagePanel.STATE = {
    /**
     * @default undefined
     * @memberof FloatingToolbarFragmentBackgroundImagePanel
     * @review
     * @type {!object}
     */
    item: _metalState.Config.object().required()
  };
  var ConnectedFloatingToolbarFragmentBackgroundImagePanel = (0, _ConnectedComponent.getConnectedComponent)(FloatingToolbarFragmentBackgroundImagePanel, ['defaultSegmentsExperienceId', 'imageSelectorURL', 'languageId', 'portletNamespace', 'segmentsExperienceId']);
  exports.ConnectedFloatingToolbarFragmentBackgroundImagePanel = ConnectedFloatingToolbarFragmentBackgroundImagePanel;

  _metalSoy["default"].register(ConnectedFloatingToolbarFragmentBackgroundImagePanel, _FloatingToolbarFragmentBackgroundImagePanel["default"]);

  var _default = ConnectedFloatingToolbarFragmentBackgroundImagePanel;
  exports["default"] = _default;
  //# sourceMappingURL=FloatingToolbarFragmentBackgroundImagePanel.es.js.map
});
//# sourceMappingURL=FloatingToolbarFragmentBackgroundImagePanel.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.126.jar: META-INF/resources/js/components/floating_toolbar/fragment_background_image/FloatingToolbarFragmentBackgroundImagePanel.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.126/js/components/floating_toolbar/fragment_background_image/FloatingToolbarFragmentBackgroundImagePanel.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', './FloatingToolbarFragmentBackgroundImagePanelDelegateTemplate.soy', '../../../actions/updateEditableValue.es', '../../../store/ConnectedComponent.es', '../../../utils/FragmentsEditorDialogUtils', '../../../utils/constants', './FloatingToolbarFragmentBackgroundImagePanel.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.FloatingToolbarFragmentBackgroundImagePanel = exports.ConnectedFloatingToolbarFragmentBackgroundImagePanel = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  require("./FloatingToolbarFragmentBackgroundImagePanelDelegateTemplate.soy");

  var _updateEditableValue = require("../../../actions/updateEditableValue.es");

  var _ConnectedComponent = require("../../../store/ConnectedComponent.es");

  var _FragmentsEditorDialogUtils = require("../../../utils/FragmentsEditorDialogUtils");

  var _constants = require("../../../utils/constants");

  var _FloatingToolbarFragmentBackgroundImagePanel = _interopRequireDefault(require("./FloatingToolbarFragmentBackgroundImagePanel.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FloatingToolbarFragmentBackgroundImagePanel
   */
  var FloatingToolbarFragmentBackgroundImagePanel = /*#__PURE__*/function (_Component) {
    _inherits(FloatingToolbarFragmentBackgroundImagePanel, _Component);

    function FloatingToolbarFragmentBackgroundImagePanel() {
      _classCallCheck(this, FloatingToolbarFragmentBackgroundImagePanel);

      return _possibleConstructorReturn(this, _getPrototypeOf(FloatingToolbarFragmentBackgroundImagePanel).apply(this, arguments));
    }

    _createClass(FloatingToolbarFragmentBackgroundImagePanel, [{
      key: "_handleSelectButtonClick",

      /**
       * Show image selector
       * @private
       * @review
       */
      value: function _handleSelectButtonClick() {
        var _this = this;

        (0, _FragmentsEditorDialogUtils.openImageSelector)({
          callback: function callback(image) {
            return _this._updateFragmentBackgroundImage(image);
          },
          imageSelectorURL: this.imageSelectorURL,
          portletNamespace: this.portletNamespace
        });
      }
      /**
       * Remove existing image if any
       * @private
       * @review
       */

    }, {
      key: "_handleClearButtonClick",
      value: function _handleClearButtonClick() {
        this._updateFragmentBackgroundImage('');
      }
      /**
       * Dispatches action to update editableValues with new background image url
       * @param {string} backgroundImageURL
       */

    }, {
      key: "_updateFragmentBackgroundImage",
      value: function _updateFragmentBackgroundImage(image) {
        this.store.dispatch((0, _updateEditableValue.updateEditableValueContentAction)(this.item.fragmentEntryLinkId, _constants.BACKGROUND_IMAGE_FRAGMENT_ENTRY_PROCESSOR, this.item.editableId, image));
      }
    }]);

    return FloatingToolbarFragmentBackgroundImagePanel;
  }(_metalComponent["default"]);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.FloatingToolbarFragmentBackgroundImagePanel = FloatingToolbarFragmentBackgroundImagePanel;
  FloatingToolbarFragmentBackgroundImagePanel.STATE = {
    /**
     * @default undefined
     * @memberof FloatingToolbarFragmentBackgroundImagePanel
     * @review
     * @type {!object}
     */
    item: _metalState.Config.object().required()
  };
  var ConnectedFloatingToolbarFragmentBackgroundImagePanel = (0, _ConnectedComponent.getConnectedComponent)(FloatingToolbarFragmentBackgroundImagePanel, ['defaultSegmentsExperienceId', 'imageSelectorURL', 'languageId', 'portletNamespace', 'segmentsExperienceId']);
  exports.ConnectedFloatingToolbarFragmentBackgroundImagePanel = ConnectedFloatingToolbarFragmentBackgroundImagePanel;

  _metalSoy["default"].register(ConnectedFloatingToolbarFragmentBackgroundImagePanel, _FloatingToolbarFragmentBackgroundImagePanel["default"]);

  var _default = ConnectedFloatingToolbarFragmentBackgroundImagePanel;
  exports["default"] = _default;
  //# sourceMappingURL=FloatingToolbarFragmentBackgroundImagePanel.es.js.map
});
//# sourceMappingURL=FloatingToolbarFragmentBackgroundImagePanel.es.js.map
